@@ -13,7 +13,7 @@
 namespace dht
 {
 /*!
- * GetPeers response message
+ * \brief GetPeers response message.
  */
 class KTORRENT_EXPORT GetPeersRsp : public RPCMsg, public PackedNodeContainer
 {
@@ -45,8 +45,6 @@ public:
         return nodes.size() == 0;
     }
 
-    typedef QSharedPointer<GetPeersRsp> Ptr;
-
 private:
     QByteArray token;
     DBItemList items;
